#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pantry
version:              0.8.3
visibility:           public
id:                   pantry-0.8.3-7LJC9V92zkc465hmB6UrK0
key:                  pantry-0.8.3-7LJC9V92zkc465hmB6UrK0
license:              BSD-3-Clause
copyright:            2018-2022 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/pantry#readme
synopsis:             Content addressable Haskell package management
description:
    Please see the README on GitHub at <https://github.com/commercialhaskell/pantry#readme>

category:             Development
abi:                  e33fef21b896e27d94808e4deb2a8283
exposed:              True
exposed-modules:
    Pantry Pantry.Internal Pantry.Internal.AesonExtended
    Pantry.Internal.Companion Pantry.Internal.Stackage
    Pantry.Internal.StaticBytes Pantry.SHA256

hidden-modules:
    Hackage.Security.Client.Repository.HttpLib.HttpClient
    Pantry.Archive Pantry.HTTP Pantry.HPack Pantry.Hackage Pantry.Repo
    Pantry.SQLite Pantry.Storage Pantry.Casa Pantry.Tree Pantry.Types
    System.IsWindows

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pantry
hs-libraries:         HSpantry-0.8.3-7LJC9V92zkc465hmB6UrK0
depends:
    Cabal-3.10.3.0 aeson-2.2.2.0-Fs8lpfl0CTvIUZfvQfMaj3
    ansi-terminal-1.1-5MUD2jLYLiA9e4scB8VtNm base-4.18.2.1
    bytestring-0.11.5.3 casa-client-0.0.3-IoRskfmGLDMILeC2UZPwyJ
    casa-types-0.0.3-69nuzeRfMnw2ps4UV8oxR7
    conduit-1.3.6.1-JGyb343VY1uGuoJjmmY2sd
    conduit-extra-1.3.8-G7cnZwS5EEUJTmnbn7fqjb containers-0.6.7
    crypton-1.0.4-JL9h5GrCbpmIrFOglrOZTL
    crypton-conduit-0.2.3-1433PrdQRJZ24A1zCppPUq
    digest-0.0.2.1-JWOwjMkQwx5F9nVaVojfVV
    filelock-0.1.1.8-3XbXlV09taMgTOx7FtUkE
    generic-deriving-1.14.7-LXLnVXLONpECqGYOG7TVpP
    hackage-security-0.6.3.2-CPp25CkxDrQ60HoDc9vhpQ
    hpack-0.38.0-6J7yauxpWhiGnwIkfvJbJU
    http-client-0.7.19-DALlHG22JR86LK61BczJck
    http-client-tls-0.3.6.4-9aLPLbyXiQrLJlGR6hoZq5
    http-conduit-2.3.9.1-9RxOIrmTuc630zbaqOY6gJ
    http-download-0.2.1.0-8fwh0DTYhJ98ZURvCDjQt5
    http-types-0.12.4-LNdcYYtCiEAAA2abLyIqKh
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5 mtl-2.3.1
    network-uri-2.6.4.2-Lsaf0h0B6LzHuoHWbm4G86
    path-0.9.6-9Wm1dSKzMc73siFftGilq4
    path-io-1.8.2-Bb4rjlP4qsJ6aPOvjxAZRU
    persistent-2.14.6.0-LVZGEReV62YCIgwBLWFEr5
    persistent-sqlite-2.13.2.0-6SOTrwf3azt8d8oXztu6w7
    primitive-0.9.1.0-KFXLETtneCW6TzlN6BZjEA
    resourcet-1.3.0-AF2iyKp8v5N69ibPjX54Ky
    rio-0.1.24.0-G56b1UrU1Dw36V8lVALZEc
    rio-orphans-0.1.2.0-3BgciGz9PzzK9jyXMAD2is
    rio-prettyprint-0.1.8.0-JsNS50VEJIg2gkQauiHO9b
    tar-conduit-0.4.1-LUeIKEUTpUFGUTzMLwZAdJ text-2.0.2
    text-metrics-0.3.3-ATgDBaZfT1jLvELDekNNSY time-1.12.2
    transformers-0.6.1.0 unix-compat-0.7.4.1-HrEOz7uUVHiH6j99wQZ7X5
    unliftio-0.2.25.1-4NwnNs4RtDwK8DYnc6XyDt
    unordered-containers-0.2.21-DZIhPqSL0N2YNV8fYQEJ8
    vector-0.13.2.0-746bkLFippyHVcwUkeKsy
    yaml-0.11.11.2-3ATQsh2l4QUFE9YTeiAwRD
    zip-archive-0.4.3.2-5eNeCDPJxFAK0ruhCSrI0V

haddock-interfaces:   /usr/share/doc/haskell-pantry/html/pantry.haddock
haddock-html:         /usr/share/doc/haskell-pantry/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

